<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Validator;
use App\Models\UserMaster;
use Illuminate\Support\Facades\Auth;
use Laravel\Sanctum\PersonalAccessToken;


class LoginController extends Controller
{
    public function login(Request $request)
    {
        // Validate input
        $validator = Validator::make($request->all(), [
            'U_Email' => 'required|email|exists:user_masters,U_Email',
            'U_Password' => 'required|min:6'
        ]);

        if ($validator->fails()) {
            return response()->json(['status' => false, 'message' => $validator->errors()], 422);
        }

        // Find user by email
        $user = UserMaster::where('U_Email', $request->U_Email)->first();

        // Verify password
        if (!$user || !Hash::check($request->U_Password, $user->U_Password)) {
            return response()->json(['status' => false, 'message' => 'Invalid email or password'], 401);
        }

        // Generate token
        $token = $user->createToken('authToken')->plainTextToken;

        return response()->json([
            'status' => true,
            'message' => 'Login Successful',
            'user' => $user,
            'token' => $token
        ], 200);
    }

    public function logout(Request $request)
    {
        // Check if there's an Authorization header with the Bearer token
        $token = $request->bearerToken();

        if (!$token) {
            return response()->json(['message' => 'Token not provided'], 401);
        }

        // Find the token using Sanctum's token repository
        $userToken = PersonalAccessToken::findToken($token);

        if (!$userToken) {
            return response()->json(['message' => 'Invalid token'], 401);
        }

        // Get the user associated with the token
        $user = $userToken->user;

        // Revoke the user's token
        $userToken->delete();

        return response()->json([
            'message' => 'User logged out successfully'
        ], 200);
    }
}
