<?php

namespace App\Http\Controllers;

use App\Models\ProfileMaster;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;
use Laravel\Sanctum\PersonalAccessToken;

class ProfileMasterController extends Controller
{
    public function ProfileUpdate(Request $request)
    {
        // Extract Bearer token from request
        $token = $request->bearerToken();

        // Check if token exists
        if (!$token) {
            return response()->json(['error' => 'Unauthorized: No token provided'], 401);
        }

        // Validate token and get the user
        $accessToken = PersonalAccessToken::findToken($token);

        if (!$accessToken) {
            return response()->json(['error' => 'Unauthorized: Invalid token'], 401);
        }

        $user = $accessToken->tokenable; // Get the user associated with the token

        if (!$user) {
            return response()->json(['error' => 'Unauthorized: User not found'], 401);
        }

        // Get logged-in user ID dynamically
        $userId = $user->U_Id;

        // Validate request data
        $validator = Validator::make($request->all(), [
            'profile_for' => 'required|string|max:50',
            'gender' => 'required|in:Male,Female,Other',
            'first_name' => 'required|string|max:100',
            'last_name' => 'required|string|max:100',
            'dob' => 'required|date',
            'height' => 'required|numeric|min:4.0|max:8.0', // Height in feet
            'religion' => 'required|string|max:255',
            'caste' => 'required|string|max:255',
            'education' => 'required|string|max:255',
            'income_min' => 'required|integer|min:0',
            'income_max' => 'required|integer|min:0|gte:income_min',
            'city' => 'required|string|max:255',
            'state' => 'required|string|max:255',
            'country' => 'required|string|max:255',
            'marital_status' => 'required|string|in:single,married,divorced,widowed',
            'occupation' => 'required|string|max:255',
        ]);

        if ($validator->fails()) {
            return response()->json(['errors' => $validator->errors()], 422);
        }

        // Update or create the profile
        $profile = ProfileMaster::updateOrCreate(
            ['U_Id' => $userId],
            [
                'profile_for' => $request->profile_for,
                'gender' => $request->gender,
                'first_name' => $request->first_name,
                'last_name' => $request->last_name,
                'dob' => $request->dob,
                'height' => $request->height ?? null,
                'religion' => $request->religion ?? null,
                'caste' => $request->caste ?? null,
                'education' => $request->education ?? null,
                'income_min' => $request->income_min ?? null,
                'income_max' => $request->income_max ?? null,
                'city' => $request->city ?? null,
                'state' => $request->state ?? null,
                'country' => $request->country ?? null,
                'marital_status' => $request->marital_status ?? null,
                'occupation' => $request->occupation ?? null,
            ]
        );

        return response()->json([
            'message' => 'Profile updated successfully',
            'profile' => $profile
        ], 200);
    }
}
