<?php

namespace App\Http\Controllers;

use App\Models\RoleMaster;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;

class RoleController extends Controller
{
    public function store(Request $request)
    {
        try {
            $validator = Validator::make($request->all(), [
                'Role_Name' => 'required|string|unique:role_masters,Role_Name|max:50'
            ]);

            if ($validator->fails()) {
                return response()->json(['message' => $validator->errors()->first()], 422);
            }

            $role = new RoleMaster();
            $role->Role_Name = $request->Role_Name;
            $role->save();

            return response()->json([
                'message' => 'Role Created Successfully',
                'role' => ['Role_Name' => $role->Role_Name] // ✅ Removing Role_Id
            ], 200);
        } catch (\Exception $e) {
            return response()->json(['message' => 'Something went wrong', 'error' => $e->getMessage()], 500);
        }
    }

    public function show($id)
    {
        $role = RoleMaster::find($id);
        if (!$role) {
            return response()->json(['message' => 'Role not found'], 404);
        }
        return response()->json(['role' => ['Role_Name' => $role->Role_Name]], 200); // ✅ Removing Role_Id
    }

    // 🚀 Edit Method (Get role details for editing)
    public function edit($id)
    {
        return $this->show($id); // ✅ Same as show
    }

    // 🚀 Update Method
    public function update(Request $request, $id)
    {
        try {
            $role = RoleMaster::find($id);
            if (!$role) {
                return response()->json(['message' => 'Role not found'], 404);
            }

            $validator = Validator::make($request->all(), [
                'Role_Name' => 'required|string|unique:role_master,Role_Name,' . $id . ',Role_Id|max:50'
            ]);

            if ($validator->fails()) {
                return response()->json(['message' => $validator->errors()->first()], 422);
            }

            $role->Role_Name = $request->Role_Name;
            $role->save();

            return response()->json([
                'message' => 'Role Updated Successfully',
                'role' => ['Role_Name' => $role->Role_Name] // ✅ Removing Role_Id
            ], 200);
        } catch (\Exception $e) {
            return response()->json(['message' => 'Something went wrong', 'error' => $e->getMessage()], 500);
        }
    }

    // 🚀 Delete Method
    public function destroy($id)
    {
        try {
            $role = RoleMaster::find($id);
            if (!$role) {
                return response()->json(['message' => 'Role not found'], 404);
            }

            $role->delete();
            return response()->json(['message' => 'Role Deleted Successfully'], 200);
        } catch (\Exception $e) {
            return response()->json(['message' => 'Something went wrong', 'error' => $e->getMessage()], 500);
        }
    }
}
