<?php

namespace App\Http\Controllers;

use App\Models\SubscriptionPlan;
use App\Models\UserSubscription;
use Illuminate\Http\Request;
use Illuminate\Support\Carbon as SupportCarbon;
use Illuminate\Support\Facades\Validator;
use Laravel\Sanctum\PersonalAccessToken;

class UserSubscriptionController extends Controller
{
    public function purchasePlan(Request $request)
    {
        $user = $this->getAuthenticatedUser($request);

        if (!$user) {
            return response()->json(['message' => 'Unauthorized'], 403);
        }

        $validator = Validator::make($request->all(), [
            'plan_id' => 'required|exists:subscription_plans,id',
        ]);

        if ($validator->fails()) {
            return response()->json(['message' => 'Validation Failed', 'errors' => $validator->errors()], 422);
        };

        // Check if user already has an active subscription
        $userSubscription = UserSubscription::where('U_Id', $user->U_Id)->latest()->first();

        if ($userSubscription && $userSubscription->isActive()) {
            return response()->json(['message' => 'You already has an active subscription'], 400);
        }

        // Get the selected plan
        $plan = SubscriptionPlan::findOrFail($request->plan_id);

        // Calculate subscription duration
        $start_date = SupportCarbon::now();
        $end_date = $start_date->copy()->addDays((int) $plan->duration);

        // Create subscription entry
        $subscription = UserSubscription::create([
            'U_Id' => $user->U_Id,
            'plan_id' => $plan->id,
            'start_date' => $start_date,
            'end_date' => $end_date,
            'status' => 'Active'
        ]);

        return response()->json(['message' => 'Subscription purchased successfully', 'subscription' => $subscription], 201);
    }


    private function getAuthenticatedUser(Request $request)
    {
        $token = $request->bearerToken();
        if (!$token) {
            return null;
        }

        $personalAccessToken = PersonalAccessToken::findToken($token);
        if (!$personalAccessToken) {
            return null;
        }

        return $personalAccessToken->tokenable; // This returns the associated user
    }
}
