<?php

use App\Http\Controllers\LoginController;
use App\Http\Controllers\MatchController;
use App\Http\Controllers\PartnerPreferenceController;
use App\Http\Controllers\ProfileMasterController;
use App\Http\Controllers\RoleController;
use App\Http\Controllers\SubscriptionPlanController;
use App\Http\Controllers\UserMasterController;
use App\Http\Controllers\UserSubscriptionController;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Route;

Route::get('/user', function (Request $request) {
    return $request->user();
})->middleware('auth:sanctum');




Route::post('/register', [UserMasterController::class, 'store']);
Route::post('/login', [LoginController::class, 'login']);
Route::post('/create_role', [RoleController::class, 'store']);
Route::post('/profile_update', [ProfileMasterController::class, 'ProfileUpdate']);


Route::get('/users', [UserMasterController::class, 'GetAllUsers']); // get all users
Route::get('/user/{id}', [UserMasterController::class, 'show']); // get a user


Route::get('/subscription-plans', [SubscriptionPlanController::class, 'index']); // Get all subscription plans
Route::post('/subscription-plans', [SubscriptionPlanController::class, 'store']); // Create a new plan (Super Admin only)
Route::put('/subscription-plans/{id}', [SubscriptionPlanController::class, 'update']); // Update a plan (Super Admin only)
Route::delete('/subscription-plans/{id}', [SubscriptionPlanController::class, 'destroy']); // Delete a plan (Super Admin only)


Route::post('/purchase-plan', [UserSubscriptionController::class, 'purchasePlan']);


Route::post('/partner-preferences/create', [PartnerPreferenceController::class, 'store']);
Route::put('/partner-preferences/update', [PartnerPreferenceController::class, 'update']);
Route::get('/partner-preferences/show', [PartnerPreferenceController::class, 'show']);
Route::delete('/partner-preferences/delete', [PartnerPreferenceController::class, 'destroy']);


// 1️⃣ Find Matches Based on Partner Preferences
Route::post('/find-matches', [MatchController::class, 'findMatches']);

// 2️⃣ Get My Matches List
Route::get('/matches', [MatchController::class, 'getMatches']);

// 3️⃣ Accept or Reject a Match
Route::post('/matches/update-status', [MatchController::class, 'updateMatchStatus']);

// 4️⃣ Get Mutual Matches (Both Users Accepted)
Route::get('/matches/mutual', [MatchController::class, 'getMutualMatches']);

// 5️⃣ Block a User (Prevent Future Matches)
Route::post('/matches/block', [MatchController::class, 'blockUser']);
